@@ -2,7 +2,7 @@ package Plack::Middleware::PrettyException;
 
 # ABSTRACT: Capture exceptions and present them as HTML or JSON
 
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 
 use 5.010;
 use strict;
@@ -41,6 +41,12 @@ sub call {
                 : $e->can('http_status') ? $e->http_status
                 :                          500;
             $r->[0] ||= 500;
+
+            if ( $r->[0] =~ /^3/ && $e->can('location') ) {
+                push( @{ $r->[1] }, Location => $e->location );
+                push( @{ $r->[2] }, $e->location ) unless $r->[2];
+            }
+
         }
         else {
             $r->[0] = 500;
@@ -58,6 +64,11 @@ sub call {
                 # all is ok!
                 return;
             }
+            if ( $r->[0] =~ /^3/ ) {
+
+                # it's a redirect
+                return;
+            }
 
             # there was an error!
 
@@ -132,7 +143,7 @@ Plack::Middleware::PrettyException - Capture exceptions and present them as HTML
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
